<?php

/**
 * @file
 * Contains status-related functions.
 */

/**
 * Displays a somewhat more in-depth status page.
 */
function closure_compiler_status() {
  module_load_include('inc', 'closure_compiler', 'closure_compiler.functions');
  $js_files = closure_compiler_get_js_files();

  $output = '<h2>Unoptimized JS Files</h2>';
  $unoptimized = array();
  foreach ($js_files['unoptimized'] as $uri => $js_file) {
    $unoptimized[] = array(
      $uri,
      date('Y-m-d H:i:s', $js_file['original_modification_time']),
      _closure_compiler_sort_filesize($js_file['original_js_size']),
      $js_file['original_gz_size'] ? _closure_compiler_sort_filesize($js_file['original_gz_size']) . ' (' . number_format($js_file['original_gz_size'] / $js_file['original_js_size'] * 100, 1) . '%)' : '',
    );
  }
  if (empty($unoptimized)) {
    $output .= '<p>No unoptimized files found</p>';
  }
  else {
    $output .= theme('table', array(
      'header' => array('File URI', 'Modification time', 'JS Size', 'GZ Size (% of original JS)'),
      'rows' => $unoptimized,
    ));
  }

  $output .= '<h2>Optimized JS Files</h2>';
  $optimized = array();
  foreach ($js_files['optimized'] as $uri => $js_file) {
    $optimized[] = array(
      $uri,
      date('Y-m-d H:i:s', $js_file['modification_time']),
      _closure_compiler_sort_filesize($js_file['js_size']) . ' (' . number_format($js_file['js_size'] / $js_file['original_js_size'] * 100, 1) . '%)',
      $js_file['original_gz_size'] ? _closure_compiler_sort_filesize($js_file['gz_size']) . ' (' . number_format($js_file['gz_size'] / $js_file['original_js_size'] * 100, 1) . '%)' : '',
    );
  }
  if (empty($optimized)) {
    $output .= '<p>No optimized files found.</p>';
  }
  else {
    $output .= theme('table', array(
      'header' => array('File URI', 'Modification time', 'JS Size (% of original JS)', 'GZ Size (% of original JS)'),
      'rows' => $optimized,
    ));
  }

  return $output;
}

/**
 * Converts a file size into a shorter SI version.
 *
 * http://stackoverflow.com/questions/2510434/
 *  php-format-bytes-to-kilobytes-megabytes-gigabytes
 */
function _closure_compiler_sort_filesize($size) {
  $units = array('B', 'KB', 'MB');
  $size = max($size, 0);
  $pow = floor(($size ? log($size) : 0) / log(1024));
  $pow = min($pow, 2); //$pow = min($pow, count($units) - 1);
  $size /= pow(1024, $pow);
  return number_format($size, 2) . ' ' . $units[$pow];
}